@@ -4,14 +4,16 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     28/05/2003
-// RCS-ID:      $Id: renderer.h,v 1.7 2004/12/21 21:12:52 mbarbon Exp $
-// Copyright:   (c) 2003-2004 Mattia Barbon
+// RCS-ID:      $Id: renderer.h,v 1.9 2005/07/30 10:23:55 mbarbon Exp $
+// Copyright:   (c) 2003-2005 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
 
 #include "cpp/v_cback.h"
 #include <wx/dc.h>
+#include <wx/clntdata.h>
+#include "cpp/helpers.h"
 
 class wxPlGridCellRenderer : public wxGridCellRenderer
 {
